@@ -21,6 +21,7 @@
 
 #include <stdlib.h>
 
+#include <gtkmm.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -40,7 +41,7 @@
 #include "callbacks.h"
 #include "smooth_refresh.h"
 #include "util.h"
-
+#include "gconf-keys.h"
 
 ProcData* ProcData::get_instance()
 {
@@ -61,6 +62,18 @@ tree_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data
 	
 }
 
+static void
+solaris_mode_changed_cb(GConfClient *client, guint id, GConfEntry *entry, gpointer data)
+{
+	ProcData *procdata = static_cast<ProcData*>(data);
+	GConfValue *value = gconf_entry_get_value (entry);
+
+	procdata->config.solaris_mode = gconf_value_get_bool(value);
+	proctable_update_all (procdata);
+}
+
+
+
 static void
 view_as_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
 {
@@ -241,6 +254,11 @@ procman_data_new (GConfClient *client)
 	pd->config.show_tree = gconf_client_get_bool (client, "/apps/procman/show_tree", NULL);
 	gconf_client_notify_add (client, "/apps/procman/show_tree", tree_changed_cb,
 				 pd, NULL, NULL);
+
+	pd->config.solaris_mode = gconf_client_get_bool(client, procman::gconf::solaris_mode.c_str(), NULL);
+	gconf_client_notify_add(client, procman::gconf::solaris_mode.c_str(), solaris_mode_changed_cb, pd, NULL, NULL);
+
+
 	pd->config.show_kill_warning = gconf_client_get_bool (client, "/apps/procman/kill_dialog", 
 							      NULL);
 	gconf_client_notify_add (client, "/apps/procman/kill_dialog", warning_changed_cb,
@@ -657,7 +675,7 @@ main (int argc, char *argv[])
 
 	startup_timestamp = get_startup_timestamp();
 
-	gtk_init(&argc, &argv);
+	Gtk::Main kit(&argc, &argv);
 	procman_debug("post gtk_init");
 
 	conn = bacon_message_connection_new ("gnome-system-monitor");
@@ -703,7 +721,7 @@ main (int argc, char *argv[])
 	create_main_window (procdata);
 	procman_debug("end create_main_window");
 	
-	proctable_update_all (procdata);
+	// proctable_update_all (procdata);
 
 	init_volume_monitor (procdata);
 
@@ -712,7 +730,7 @@ main (int argc, char *argv[])
  	gtk_widget_show(procdata->app);
        
 	procman_debug("begin gtk_main");
-	gtk_main ();
+	kit.run();
 	
 	procman_free_data (procdata);
 
